@@ -49,7 +49,10 @@ import org.kie.workbench.common.dmn.client.widgets.panel.DMNGridPanel;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
+import org.kie.workbench.common.stunner.core.command.CommandResult;
+import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.columns.RowNumberColumn;
@@ -213,17 +216,21 @@ public class RelationGrid extends BaseExpressionGrid<Relation, RelationGridData,
     void addColumn(final int index) {
         expression.ifPresent(relation -> {
             final InformationItem informationItem = new InformationItem();
-            informationItem.setName(new Name("Column"));
             final RelationColumn relationColumn = makeRelationColumn(informationItem);
+            informationItem.setName(new Name());
 
-            sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
-                                          new AddRelationColumnCommand(relation,
-                                                                       informationItem,
-                                                                       model,
-                                                                       relationColumn,
-                                                                       index,
-                                                                       uiModelMapper,
-                                                                       this::resize));
+            final CommandResult<CanvasViolation> result = sessionCommandManager.execute((AbstractCanvasHandler) sessionManager.getCurrentSession().getCanvasHandler(),
+                                                                                        new AddRelationColumnCommand(relation,
+                                                                                                                     informationItem,
+                                                                                                                     model,
+                                                                                                                     relationColumn,
+                                                                                                                     index,
+                                                                                                                     uiModelMapper,
+                                                                                                                     this::resize));
+
+            if (!CommandUtils.isError(result)) {
+                relationColumn.startEditingHeaderCell(0);
+            }
         });
     }
 
