@@ -25,11 +25,10 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
 import org.kie.workbench.common.dmn.client.decision.DecisionNavigatorPresenter;
+import org.kie.workbench.common.dmn.client.editors.toolbar.ToolbarStateHandler;
 import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCache;
 import org.kie.workbench.common.dmn.client.widgets.grid.ExpressionGridCacheImpl;
-import org.kie.workbench.common.dmn.client.widgets.toolbar.DMNEditorToolbar;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.SessionPresenter;
-import org.kie.workbench.common.stunner.client.widgets.toolbar.ToolbarCommand;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.session.impl.ManagedSession;
@@ -37,12 +36,11 @@ import org.mockito.Mock;
 import org.uberfire.mvp.Command;
 
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.atLeast;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.verifyNoMoreInteractions;
 import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
@@ -60,7 +58,7 @@ public class ExpressionEditorTest {
     private DecisionNavigatorPresenter decisionNavigator;
 
     @Mock
-    private DMNEditorToolbar editorToolbar;
+    private ToolbarStateHandler toolbarStateHandler;
 
     @Mock
     private HasName hasName;
@@ -85,23 +83,61 @@ public class ExpressionEditorTest {
 
         testedEditor = spy(new ExpressionEditor(view,
                                                 decisionNavigator));
-        when(sessionPresenter.getToolbar()).thenReturn(editorToolbar);
-        when(editorToolbar.isEnabled(any(ToolbarCommand.class))).thenReturn(true);
         when(session.getCanvasControl(eq(ExpressionGridCache.class))).thenReturn(expressionGridCache);
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testInit() {
-        testedEditor.init(sessionPresenter);
+    public void testSetExpression() {
+        setupExpression(toolbarStateHandler);
 
-        verify(sessionPresenter).getToolbar();
+        verify(view).setExpression(eq(NODE_UUID),
+                                   eq(hasExpression),
+                                   eq(Optional.of(hasName)));
+        verify(toolbarStateHandler).enterGridView();
     }
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testSetExpression() {
-        testedEditor.init(sessionPresenter);
+    public void testExitWithCommand() {
+        setupExpression(toolbarStateHandler);
+
+        testedEditor.setExitCommand(command);
+
+        testedEditor.exit();
+
+        verify(decisionNavigator).clearSelections();
+        verify(toolbarStateHandler).enterGraphView();
+        verify(command).execute();
+        assertEquals(Optional.empty(), testedEditor.getExitCommand());
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testSetExpressionWithoutToolbar() {
+        setupExpression(null);
+
+        verifyNoMoreInteractions(toolbarStateHandler);
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testExitWithCommandWithoutToolbar() {
+        setupExpression(null);
+
+        testedEditor.setExitCommand(command);
+
+        testedEditor.exit();
+
+        verify(decisionNavigator).clearSelections();
+        verifyNoMoreInteractions(toolbarStateHandler);
+        verify(command).execute();
+        assertEquals(Optional.empty(), testedEditor.getExitCommand());
+    }
+
+    @SuppressWarnings("unchecked")
+    private void setupExpression(final ToolbarStateHandler toolbarStateHandler) {
+        testedEditor.setToolbarStateHandler(toolbarStateHandler);
 
         testedEditor.setExpression(NODE_UUID,
                                    hasExpression,
@@ -110,29 +146,10 @@ public class ExpressionEditorTest {
         verify(view).setExpression(eq(NODE_UUID),
                                    eq(hasExpression),
                                    eq(Optional.of(hasName)));
-        verify(editorToolbar, atLeast(1)).disable(any(ToolbarCommand.class));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void testExitWithCommand() {
-        testedEditor.init(sessionPresenter);
-        testedEditor.setExpression(NODE_UUID,
-                                   hasExpression,
-                                   Optional.of(hasName));
-        testedEditor.setExitCommand(command);
-
-        testedEditor.exit();
-
-        verify(decisionNavigator).clearSelections();
-        verify(editorToolbar, atLeast(1)).enable(any(ToolbarCommand.class));
-        verify(command).execute();
-        assertEquals(Optional.empty(), testedEditor.getExitCommand());
     }
 
     @Test
     public void testOnCanvasFocusedSelectionEvent() {
-
         final CanvasHandler canvasHandler = mock(CanvasHandler.class);
         final String uuid = "uuid";
         final CanvasSelectionEvent event = new CanvasSelectionEvent(canvasHandler, uuid);
