@@ -139,6 +139,12 @@ public class InvocationEditorDefinitionTest {
     public void testModelDefinition() {
         final Optional<Invocation> oModel = definition.getModelClass();
         assertTrue(oModel.isPresent());
+    }
+
+    @Test
+    public void testModelEnrichment() {
+        final Optional<Invocation> oModel = definition.getModelClass();
+        definition.enrich(Optional.empty(), oModel);
 
         final Invocation model = oModel.get();
         assertNotNull(model.getExpression());
@@ -148,7 +154,7 @@ public class InvocationEditorDefinitionTest {
                      model.getBinding().size());
 
         assertNotNull(model.getBinding().get(0).getParameter());
-        assertEquals("p0",
+        assertEquals(InvocationDefaultValueUtilities.PREFIX + "1",
                      model.getBinding().get(0).getParameter().getName().getValue());
 
         assertNull(model.getBinding().get(0).getExpression());
