@@ -16,17 +16,23 @@
 
 package org.kie.workbench.common.forms.dynamic.client.rendering.renderers.selectors.listBox;
 
+import java.util.Collections;
+import java.util.List;
 import java.util.Map;
-import java.util.Set;
+import java.util.stream.Collectors;
 
 import com.google.gwt.user.client.ui.HTML;
-import com.google.gwt.user.client.ui.IsWidget;
 import org.gwtbootstrap3.client.ui.ValueListBox;
 import org.jboss.errai.databinding.client.api.Converter;
+import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.forms.common.rendering.client.util.valueConverters.ValueConvertersFactory;
 import org.kie.workbench.common.forms.common.rendering.client.widgets.util.DefaultValueListBoxRenderer;
+import org.kie.workbench.common.forms.dynamic.client.rendering.formGroups.FormGroup;
+import org.kie.workbench.common.forms.dynamic.client.rendering.formGroups.impl.def.DefaultFormGroup;
 import org.kie.workbench.common.forms.dynamic.client.rendering.renderers.RequiresValueConverter;
 import org.kie.workbench.common.forms.dynamic.client.rendering.renderers.selectors.SelectorFieldRenderer;
+import org.kie.workbench.common.forms.dynamic.client.resources.i18n.FormRenderingConstants;
+import org.kie.workbench.common.forms.dynamic.service.shared.RenderMode;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.SelectorOption;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.definition.ListBoxBaseDefinition;
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.basic.selectors.listBox.type.ListBoxFieldType;
@@ -35,25 +41,65 @@ public abstract class AbstractListBoxFieldRenderer<FIELD extends ListBoxBaseDefi
         extends SelectorFieldRenderer<FIELD, OPTION, TYPE>
         implements RequiresValueConverter {
 
-    protected DefaultValueListBoxRenderer<TYPE> optionsRenderer = new DefaultValueListBoxRenderer();
+    protected DefaultValueListBoxRenderer<TYPE> optionsRenderer = new DefaultValueListBoxRenderer<>();
 
-    protected ValueListBox<TYPE> widgetList = new ValueListBox<>(optionsRenderer);
+    protected ValueListBox<TYPE> widgetList;
+
+    private final TranslationService translationService;
+
+    public AbstractListBoxFieldRenderer(TranslationService translationService) {
+        this.translationService = translationService;
+
+        widgetList = getListWidget();
+    }
+
+    protected ValueListBox<TYPE> getListWidget() {
+        return new ValueListBox<>(optionsRenderer);
+    }
 
     @Override
     public String getName() {
         return ListBoxFieldType.NAME;
     }
 
+    @Override
+    protected FormGroup getFormGroup(RenderMode renderMode) {
+        DefaultFormGroup formGroup = formGroupsInstance.get();
+
+        if (renderMode.equals(RenderMode.PRETTY_MODE)) {
+            formGroup.render(new HTML(),
+                             field);
+        } else {
+            String inputId = generateUniqueId();
+            widgetList.setId(inputId);
+            widgetList.setName(fieldNS);
+            widgetList.setEnabled(!field.getReadOnly());
+            refreshSelectorOptions();
+
+            formGroup.render(inputId,
+                             widgetList,
+                             field);
+        }
+
+        return formGroup;
+    }
+
     @Override
     protected void refreshInput(Map<TYPE, String> optionsValues,
                                 TYPE selectedValue) {
-        Set<TYPE> values = optionsValues.keySet();
+        List<TYPE> values = optionsValues.keySet().stream().collect(Collectors.toList());
 
-        boolean hasEmpty = values.contains(null) || values.contains(getEmptyValue());
-
-        if (!hasEmpty) {
-            optionsValues.put(null,
-                              "");
+        if (field.getAddEmptyOption()) {
+            if (!values.contains(null)) {
+                values.add(0,
+                           null);
+                optionsValues.put(null,
+                                  translationService.getTranslation(FormRenderingConstants.ListBoxFieldRendererEmptyOptionText));
+            } else {
+                Collections.swap(values,
+                                 values.indexOf(null),
+                                 0);
+            }
         }
 
         if (widgetList.getValue() == null && optionsValues.containsKey(selectedValue)) {
@@ -61,27 +107,12 @@ public abstract class AbstractListBoxFieldRenderer<FIELD extends ListBoxBaseDefi
         }
 
         optionsRenderer.setValues(optionsValues);
-        widgetList.setAcceptableValues(optionsValues.keySet());
-    }
 
-    @Override
-    public void initInputWidget() {
-        widgetList.setEnabled(!field.getReadOnly());
-        refreshSelectorOptions();
+        widgetList.setAcceptableValues(values);
     }
 
     public abstract TYPE getEmptyValue();
 
-    @Override
-    public IsWidget getPrettyViewWidget() {
-        return new HTML();
-    }
-
-    @Override
-    public IsWidget getInputWidget() {
-        return widgetList;
-    }
-
     @Override
     public String getSupportedCode() {
         return ListBoxBaseDefinition.FIELD_TYPE.getTypeName();
