@@ -33,9 +33,15 @@ import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.TableCo
 import org.kie.workbench.common.forms.fields.shared.fieldTypes.relations.multipleSubform.definition.MultipleSubFormFieldDefinition;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
 
 @RunWith(MockitoJUnitRunner.class)
 public class BeanPropertiesProviderTest extends AbstractDataObjectFinderTest {
@@ -62,7 +68,7 @@ public class BeanPropertiesProviderTest extends AbstractDataObjectFinderTest {
 
         currentEditedMeta = new TableColumnMeta();
 
-        context = new FormEditorRenderingContext(path);
+        context = new FormEditorRenderingContext("", path);
 
         context.setModel(currentEditedMeta);
     }
@@ -109,7 +115,7 @@ public class BeanPropertiesProviderTest extends AbstractDataObjectFinderTest {
 
         field.setStandaloneClassName(TYPE_NAME);
 
-        parentContext = new FormEditorRenderingContext(path);
+        parentContext = new FormEditorRenderingContext("", path);
 
         parentContext.setModel(field);
 
