@@ -18,8 +18,9 @@ package org.kie.workbench.common.screens.datamodeller.client;
 
 import java.util.Arrays;
 import java.util.Collections;
+import java.util.Optional;
 
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
 import org.guvnor.messageconsole.events.PublishBatchMessagesEvent;
 import org.guvnor.messageconsole.events.UnpublishMessagesEvent;
@@ -183,7 +184,7 @@ public class DataModelerScreenPresenterTest
                      context.getDataModel());
         assertEquals(testObject1,
                      context.getDataObject());
-        assertEquals(kieProject,
+        assertEquals(kieModule,
                      context.getCurrentProject());
         assertEquals(testPackages,
                      context.getCurrentProjectPackages());
@@ -303,7 +304,7 @@ public class DataModelerScreenPresenterTest
                      context.getDataModel());
         assertEquals(null,
                      context.getDataObject());
-        assertEquals(kieProject,
+        assertEquals(kieModule,
                      context.getCurrentProject());
         assertEquals(testPackages,
                      context.getCurrentProjectPackages());
@@ -595,7 +596,10 @@ public class DataModelerScreenPresenterTest
 
     @Test
     public void testMakeMenuBar() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+
+        final DataModelerScreenPresenter presenter = spy(this.presenter);
+
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
@@ -604,11 +608,13 @@ public class DataModelerScreenPresenterTest
         verify(fileMenuBuilder).addCopy(any(Command.class));
         verify(fileMenuBuilder).addRename(any(Command.class));
         verify(fileMenuBuilder).addDelete(any(Command.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
+        verify(presenter).addDownloadMenuItem(fileMenuBuilder);
     }
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
@@ -621,5 +627,6 @@ public class DataModelerScreenPresenterTest
                never()).addRename(any(Command.class));
         verify(fileMenuBuilder,
                never()).addDelete(any(Command.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
     }
-}
\ No newline at end of file
+}
