@@ -21,10 +21,14 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.stream.Stream;
+
+import javax.enterprise.event.Event;
 
 import org.ext.uberfire.social.activities.model.SocialUser;
 import org.ext.uberfire.social.activities.service.SocialUserRepositoryAPI;
-import org.guvnor.common.services.project.context.WorkspaceProjectContextChangeEvent;
+import org.guvnor.common.services.project.backend.server.utils.PathUtil;
+import org.guvnor.common.services.project.events.NewProjectEvent;
 import org.guvnor.common.services.project.model.GAV;
 import org.guvnor.common.services.project.model.Module;
 import org.guvnor.common.services.project.model.POM;
@@ -34,15 +38,16 @@ import org.guvnor.common.services.project.service.DeploymentMode;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
+import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.Repository;
 import org.guvnor.structure.repositories.RepositoryEnvironmentConfigurations;
 import org.guvnor.structure.repositories.RepositoryService;
 import org.guvnor.structure.repositories.impl.git.GitRepository;
+import org.guvnor.structure.security.RepositoryAction;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.screens.examples.model.ExampleOrganizationalUnit;
 import org.kie.workbench.common.screens.examples.model.ExampleProject;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
 import org.kie.workbench.common.screens.examples.service.ExamplesService;
@@ -67,20 +72,24 @@ import org.mockito.Captor;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.file.NoSuchFileException;
+import org.uberfire.java.nio.file.spi.FileSystemProvider;
+import org.uberfire.java.nio.fs.jgit.JGitFileSystem;
+import org.uberfire.java.nio.fs.jgit.JGitPathImpl;
 import org.uberfire.paging.PageResponse;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.security.authz.AuthorizationManager;
+import org.uberfire.spaces.Space;
 
-import static java.util.Collections.singletonList;
+import static java.util.Collections.emptyList;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertSame;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyList;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.same;
 import static org.mockito.Mockito.doReturn;
@@ -96,6 +105,9 @@ public class LibraryServiceImplTest {
     @Mock
     private OrganizationalUnitService ouService;
 
+    @Mock
+    private AuthorizationManager authorizationManager;
+
     @Mock
     private WorkspaceProjectService projectService;
 
@@ -129,6 +141,14 @@ public class LibraryServiceImplTest {
     @Mock
     private RepositoryService repositoryService;
 
+    @Mock
+    private Event<NewProjectEvent> newProjectEvent;
+
+    @Mock
+    private PathUtil pathUtil;
+
+    private final PathUtil realPathUtil = new PathUtil();
+
     @Mock
     private OrganizationalUnit ou1;
 
@@ -184,7 +204,7 @@ public class LibraryServiceImplTest {
         libraryService = spy(new LibraryServiceImpl(ouService,
                                                     refactoringQueryService,
                                                     preferences,
-                                                    mock(AuthorizationManager.class),
+                                                    authorizationManager,
                                                     mock(SessionInfo.class),
                                                     explorerServiceHelper,
                                                     projectService,
@@ -194,7 +214,9 @@ public class LibraryServiceImplTest {
                                                     ioService,
                                                     internalPreferences,
                                                     socialUserRepositoryAPI,
-                                                    indexOracle
+                                                    indexOracle,
+                                                    newProjectEvent,
+                                                    pathUtil
         ));
     }
 
@@ -232,19 +254,33 @@ public class LibraryServiceImplTest {
 
     @Test
     public void getLibraryInfoTest() {
-        final Path path = mockPath("file://the_project");
-        final WorkspaceProject project = mock(WorkspaceProject.class);
-        when(project.getRootPath()).thenReturn(path);
+        final Path path1 = mockPath("file://project1");
+        final WorkspaceProject project1 = mock(WorkspaceProject.class);
+        final Repository repository1 = mock(Repository.class);
+        when(project1.getRootPath()).thenReturn(path1);
+        when(project1.getRepository()).thenReturn(repository1);
+
+        final Path path2 = mockPath("file://project2");
+        final WorkspaceProject project2 = mock(WorkspaceProject.class);
+        final Repository repository2 = mock(Repository.class);
+        when(project2.getRootPath()).thenReturn(path2);
+        when(project2.getRepository()).thenReturn(repository2);
+
+        doReturn(true).when(authorizationManager).authorize(same(repository2),
+                                                            eq(RepositoryAction.READ),
+                                                            any());
+
         doReturn(true).when(ioService).exists(any());
 
         final Set<WorkspaceProject> projects = new HashSet<>();
-        projects.add(project);
+        projects.add(project1);
+        projects.add(project2);
         doReturn(projects).when(projectService).getAllWorkspaceProjects(ou1);
 
         final LibraryInfo libraryInfo = libraryService.getLibraryInfo(ou1);
 
-        assertEquals(new HashSet<>(projects),
-                     libraryInfo.getProjects());
+        assertEquals(1, libraryInfo.getProjects().size());
+        assertSame(project2, libraryInfo.getProjects().iterator().next());
     }
 
     @Test
@@ -313,11 +349,10 @@ public class LibraryServiceImplTest {
 
     @Test
     public void emptyFirstPage() throws Exception {
-        final WorkspaceProject project = spy(WorkspaceProject.class);
         final Branch branch = mock(Branch.class);
+        final WorkspaceProject project = spy(new WorkspaceProject(ou1, repo1, branch, null));
         final Path path = mock(Path.class);
 
-        when(project.getBranch()).thenReturn(branch);
         when(branch.getPath()).thenReturn(path);
         when(path.toURI()).thenReturn("file://a/b/c");
 
@@ -356,12 +391,14 @@ public class LibraryServiceImplTest {
     @Test
     public void queryWithAFilter() throws Exception {
 
-        final WorkspaceProject project = spy(WorkspaceProject.class);
         final Branch branch = mock(Branch.class);
         final Path path = mockPath("file://the_project");
+        final WorkspaceProject project =  spy(new WorkspaceProject(mock(OrganizationalUnit.class),
+                                                               repo1,
+                                                               branch,
+                                                               null));
 
         when(branch.getPath()).thenReturn(path);
-        when(project.getBranch()).thenReturn(branch);
 
         doReturn(true).when(ioService).exists(any());
 
@@ -403,11 +440,13 @@ public class LibraryServiceImplTest {
 
         final Path path = mockPath("file://the_project");
 
-        final WorkspaceProject project = spy(WorkspaceProject.class);
         final Branch branch = mock(Branch.class);
 
-        when(project.getBranch()).thenReturn(branch);
         when(branch.getPath()).thenReturn(path);
+        final WorkspaceProject project = spy(new WorkspaceProject(ou1,
+                                                                  repo1,
+                                                                  branch,
+                                                                  null));
 
         doReturn(true).when(ioService).exists(any());
 
@@ -543,27 +582,6 @@ public class LibraryServiceImplTest {
                      loadedExampleProjects);
     }
 
-    @Test
-    public void importProjectFromExampleTest() {
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
-        final ExampleProject exampleProject = mock(ExampleProject.class);
-
-        final WorkspaceProject project = mock(WorkspaceProject.class);
-        final Module module = mock(Module.class);
-        doReturn(module).when(project).getMainModule();
-
-        final WorkspaceProjectContextChangeEvent projectContextChangeEvent = mock(WorkspaceProjectContextChangeEvent.class);
-        doReturn(project).when(projectContextChangeEvent).getWorkspaceProject();
-        doReturn(projectContextChangeEvent).when(examplesService).setupExamples(any(ExampleOrganizationalUnit.class),
-                                                                                anyList());
-
-        final WorkspaceProject importedProject = libraryService.importProject(organizationalUnit,
-                                                                              exampleProject);
-
-        assertEquals(module,
-                     importedProject.getMainModule());
-    }
-
     @Test
     public void importProjectWithCredentialsTest() {
         final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
@@ -622,32 +640,80 @@ public class LibraryServiceImplTest {
 
     @Test
     public void importDefaultProjectTest() {
-        final Repository repository = mock(Repository.class);
-        when(repository.getAlias()).thenReturn("example");
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
-        when(organizationalUnit.getName()).thenReturn("ou");
-        when(organizationalUnit.getIdentifier()).thenReturn("ou");
-        when(organizationalUnit.getRepositories()).thenReturn(singletonList(repository));
-        when(ouService.getOrganizationalUnits()).thenReturn(singletonList(organizationalUnit));
+        final OrganizationalUnit organizationalUnit = new OrganizationalUnitImpl("myteam", "admin", "org.whatever");
+        organizationalUnit.getRepositories();
 
-        final ExampleProject exampleProject = mock(ExampleProject.class);
-        doReturn("example").when(exampleProject).getName();
+        final Path exampleRoot = mock(Path.class);
+        final org.uberfire.java.nio.file.Path exampleRootNioPath = mock(org.uberfire.java.nio.file.Path.class);
+        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
+        final ExampleProject exampleProject = new ExampleProject(exampleRoot, "example", "description", emptyList());
 
-        final WorkspaceProject project = mock(WorkspaceProject.class);
-        final Module module = mock(Module.class);
-        doReturn(module).when(project).getMainModule();
-        final WorkspaceProjectContextChangeEvent projectContextChangeEvent = mock(WorkspaceProjectContextChangeEvent.class);
-        doReturn(project).when(projectContextChangeEvent).getWorkspaceProject();
-        doReturn(projectContextChangeEvent).when(examplesService).setupExamples(any(ExampleOrganizationalUnit.class),
-                                                                                anyList());
+        String repoURL = "file:///some/repo/url";
+        when(pathUtil.getNiogitRepoPath(any())).thenReturn(repoURL);
+
+        final Repository repository = new GitRepository("example", new Space("myteam"));
+        final WorkspaceProject project = new WorkspaceProject(organizationalUnit,
+                                                              repository,
+                                                              new Branch("master", mock(Path.class)),
+                                                              new Module());
+        when(projectService.resolveProject(repository)).thenReturn(project);
+        when(repositoryService.createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), any())).thenReturn(repository);
 
         final WorkspaceProject importedProject = libraryService.importProject(organizationalUnit,
                                                                               exampleProject);
 
-        assertEquals(module,
-                     importedProject.getMainModule());
-        verify(examplesService).setupExamples(new ExampleOrganizationalUnit(organizationalUnit.getName()),
-                                              singletonList(exampleProject));
+        assertSame(project, importedProject);
+        final ArgumentCaptor<RepositoryEnvironmentConfigurations> configsCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
+        verify(repositoryService).createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), configsCaptor.capture());
+        final RepositoryEnvironmentConfigurations configs = configsCaptor.getValue();
+        assertEquals(repoURL, configs.getOrigin());
+        assertNull(configs.getSubdirectory());
+        verify(projectService).resolveProject(repository);
+    }
+
+    @Test
+    public void importProjectInSubdirectory() {
+        final OrganizationalUnit organizationalUnit = new OrganizationalUnitImpl("myteam", "admin", "org.whatever");
+        organizationalUnit.getRepositories();
+
+
+        final String exampleURI = "default://master@system/repo/example";
+        final Path exampleRoot = PathFactory.newPath("example", exampleURI);
+        final JGitFileSystem fs = mock(JGitFileSystem.class);
+        final FileSystemProvider provider = mock(FileSystemProvider.class);
+        when(fs.provider()).thenReturn(provider);
+        final org.uberfire.java.nio.file.Path exampleRootNioPath = JGitPathImpl.create(fs, "/example", "master@system/repo", true);
+        final org.uberfire.java.nio.file.Path repoRoot = exampleRootNioPath.getParent();
+        when(fs.getRootDirectories()).thenReturn(() -> Stream.of(repoRoot).iterator());
+        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
+        when(pathUtil.stripProtocolAndBranch(any())).then(inv -> realPathUtil.stripProtocolAndBranch(inv.getArgumentAt(0, String.class)));
+        when(pathUtil.stripRepoNameAndSpace(any())).then(inv -> realPathUtil.stripRepoNameAndSpace(inv.getArgumentAt(0, String.class)));
+        when(pathUtil.convert(any(org.uberfire.java.nio.file.Path.class))).then(inv -> realPathUtil.convert(inv.getArgumentAt(0, org.uberfire.java.nio.file.Path.class)));
+        when(pathUtil.extractBranch(any())).then(inv -> realPathUtil.extractBranch(inv.getArgumentAt(0, String.class)));
+
+        final ExampleProject exampleProject = new ExampleProject(exampleRoot, "example", "description", emptyList());
+
+        String repoURL = "file:///some/repo/url";
+        when(pathUtil.getNiogitRepoPath(any())).thenReturn(repoURL);
+
+        final Repository repository = new GitRepository("example", new Space("myteam"));
+        final WorkspaceProject project = new WorkspaceProject(organizationalUnit,
+                                                              repository,
+                                                              new Branch("master", mock(Path.class)),
+                                                              new Module());
+        when(projectService.resolveProject(repository)).thenReturn(project);
+        when(repositoryService.createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), any())).thenReturn(repository);
+
+        final WorkspaceProject importedProject = libraryService.importProject(organizationalUnit,
+                                                                              exampleProject);
+
+        assertSame(project, importedProject);
+        final ArgumentCaptor<RepositoryEnvironmentConfigurations> configsCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
+        verify(repositoryService).createRepository(same(organizationalUnit), eq(GitRepository.SCHEME.toString()), any(), configsCaptor.capture());
+        final RepositoryEnvironmentConfigurations configs = configsCaptor.getValue();
+        assertEquals(repoURL, configs.getOrigin());
+        assertEquals("example", configs.getSubdirectory());
+        verify(projectService).resolveProject(repository);
     }
 
     @Test
@@ -707,4 +773,19 @@ public class LibraryServiceImplTest {
         assertEquals("user",
                      users.get(1).getUserName());
     }
+
+    @Test
+    public void testGetNumberOfAssets() throws Exception {
+        final Path path = mock(Path.class);
+        final WorkspaceProject project = mock(WorkspaceProject.class);
+        final ProjectAssetsQuery query = mock(ProjectAssetsQuery.class);
+
+        doReturn(project).when(query).getProject();
+        doReturn(path).when(project).getRootPath();
+        doReturn("some.unique.uri").when(path).toURI();
+
+        libraryService.getNumberOfAssets(query);
+
+        verify(refactoringQueryService).queryHitCount(any(RefactoringPageRequest.class));
+    }
 }
