@@ -16,18 +16,24 @@
 
 package org.kie.workbench.common.workbench.client.error;
 
+import javax.enterprise.context.Dependent;
+import javax.inject.Inject;
+
 import com.google.gwt.user.client.Window;
-import org.dashbuilder.dataset.exception.*;
+import org.dashbuilder.dataset.exception.DataSetLookupException;
 import org.jboss.errai.bus.client.api.InvalidBusContentException;
-import org.jboss.errai.bus.client.api.messaging.Message;
 import org.kie.server.api.exception.KieServicesHttpException;
+import org.kie.workbench.common.workbench.client.entrypoint.GenericErrorPopup;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
-import org.uberfire.ext.widgets.common.client.callbacks.DefaultErrorCallback;
 import org.uberfire.ext.widgets.common.client.common.popups.YesNoCancelPopup;
 import org.uberfire.ext.widgets.common.client.common.popups.errors.ErrorPopup;
 import org.uberfire.ext.widgets.common.client.resources.i18n.CommonConstants;
 
-public class DefaultWorkbenchErrorCallback extends DefaultErrorCallback {
+@Dependent
+public class DefaultWorkbenchErrorCallback {
+
+    @Inject
+    private GenericErrorPopup genericErrorPopup;
 
     public static boolean isKieServerForbiddenException(final Throwable throwable) {
         if (throwable instanceof KieServicesHttpException && ((KieServicesHttpException) throwable).getHttpCode() == 403) {
@@ -57,32 +63,48 @@ public class DefaultWorkbenchErrorCallback extends DefaultErrorCallback {
         return throwable instanceof InvalidBusContentException;
     }
 
-    @Override
-    public boolean error(final Message message,
-                         final Throwable throwable) {
+    public void error(final Throwable throwable) {
+
         if (isInvalidBusContentException(throwable)) {
-            final YesNoCancelPopup result = YesNoCancelPopup.newYesNoCancelPopup(DefaultWorkbenchConstants.INSTANCE.SessionTimeout(),
-                                                                                 DefaultWorkbenchConstants.INSTANCE.InvalidBusResponseProbablySessionTimeout(),
-                                                                                 Window.Location::reload,
-                                                                                 null,
-                                                                                 () -> {});
+            final YesNoCancelPopup result = YesNoCancelPopup.newYesNoCancelPopup(
+                    DefaultWorkbenchConstants.INSTANCE.SessionTimeout(),
+                    DefaultWorkbenchConstants.INSTANCE.InvalidBusResponseProbablySessionTimeout(),
+                    Window.Location::reload,
+                    null,
+                    () -> {
+                    });
+
             result.clearScrollHeight();
             result.show();
-            return false;
-        } else if (isKieServerForbiddenException(throwable)) {
+            return;
+        }
+
+        if (isKieServerForbiddenException(throwable)) {
             ErrorPopup.showMessage(DefaultWorkbenchConstants.INSTANCE.KieServerError403());
-            return false;
-        } else if (isKieServerUnauthorizedException(throwable)) {
+            return;
+        }
+
+        if (isKieServerUnauthorizedException(throwable)) {
             ErrorPopup.showMessage(DefaultWorkbenchConstants.INSTANCE.KieServerError401());
-            return false;
-        } else if (throwable instanceof KieServicesHttpException) {
+            return;
+        }
+
+        if (throwable instanceof KieServicesHttpException) {
             KieServicesHttpException ex = (KieServicesHttpException) throwable;
             ErrorPopup.showMessage(CommonConstants.INSTANCE.ExceptionGeneric0(ex.getExceptionMessage()));
-            return false;
-        } else {
-            return super.error(message,
-                               throwable);
+            return;
         }
+
+        genericErrorPopup.setup("Uncaught exception: " + extractMessageRecursively(throwable));
+        genericErrorPopup.show();
     }
 
+
+    private String extractMessageRecursively(final Throwable t) {
+        if (t.getCause() == null) {
+            return t.getMessage();
+        }
+
+        return t.getMessage() + " Caused by: " + extractMessageRecursively(t.getCause());
+    }
 }
\ No newline at end of file
