@@ -23,8 +23,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
-import javax.annotation.concurrent.NotThreadSafe;
-
 import org.apache.lucene.analysis.Analyzer;
 import org.apache.lucene.index.Term;
 import org.apache.lucene.search.TermQuery;
@@ -38,7 +36,6 @@ import org.uberfire.ext.metadata.io.KObjectUtil;
 
 import static org.mockito.Mockito.*;
 
-@NotThreadSafe
 public class IndexUpdatedResourcesTest extends BaseIndexingTest {
 
     @Test
