@@ -15,8 +15,8 @@
  */
 package org.kie.workbench.common.services.backend.compiler.nio.impl;
 
-import java.nio.file.DirectoryStream;
-import java.nio.file.Path;
+import org.uberfire.java.nio.file.DirectoryStream;
+import org.uberfire.java.nio.file.Path;
 
 /***
  * Filter used with DirectoryStreams to avoid the load of hidden files
@@ -27,10 +27,7 @@ public class DotFileFilter implements DirectoryStream.Filter<Path> {
     }
 
     public boolean accept(Path path) {
-        if (path != null) {
-            return path.getFileName().toString().startsWith(".");
-        } else {
-            return false;
-        }
+        String fileName = path.getFileName().toString();
+        return fileName.startsWith(".");
     }
 }
