@@ -293,20 +293,22 @@ public class LocationControlImpl
                 }).collect(Collectors.toList());
     }
 
+    @Override
+    protected void doClear() {
+        ifSelectionManager(s -> s.getControl().setBoundsConstraint(null));
+        selectedIDs.clear();
+        super.doClear();
+    }
+
     @Override
     protected void doDestroy() {
         clear();
+        getWiresManager().setLocationAcceptor(ILocationAcceptor.ALL);
         commandManagerProvider = null;
         boundsConstraint = null;
         super.doDestroy();
     }
 
-    private void clear() {
-        getWiresManager().setLocationAcceptor(ILocationAcceptor.ALL);
-        ifSelectionManager(s -> s.getControl().setBoundsConstraint(null));
-        selectedIDs.clear();
-    }
-
     void onCanvasSelectionEvent(final @Observes CanvasSelectionEvent event) {
         checkNotNull("event",
                      event);
