@@ -69,6 +69,7 @@ public class ConnectorDragProxyImpl implements ConnectorDragProxy<AbstractCanvas
                                                                           final int x,
                                                                           final int y,
                                                                           final DragProxyCallback callback) {
+        clear();
         // Source connector's shape - Obtain the shape for the source node.
         final Node<View<?>, Edge> sourceNode = item.getSourceNode();
         final Shape<?> sourceNodeShape = getCanvas().getShape(sourceNode.getUUID());
@@ -140,7 +141,6 @@ public class ConnectorDragProxyImpl implements ConnectorDragProxy<AbstractCanvas
                                                callback.onComplete(x,
                                                                    y);
                                                deregisterTransientConnector();
-                                               getCanvas().draw();
                                            }
                                        });
         return this;
@@ -148,17 +148,15 @@ public class ConnectorDragProxyImpl implements ConnectorDragProxy<AbstractCanvas
 
     @Override
     public void clear() {
-        if (null != this.shapeViewDragProxyFactory) {
-            this.shapeViewDragProxyFactory.clear();
-        }
+        shapeViewDragProxyFactory.clear();
         deregisterTransientConnector();
     }
 
     public void destroy() {
-        clear();
-        this.graphBoundsIndexer.destroy();
-        this.shapeViewDragProxyFactory.destroy();
-        this.canvasHandler = null;
+        deregisterTransientConnector();
+        shapeViewDragProxyFactory.destroy();
+        graphBoundsIndexer.destroy();
+        canvasHandler = null;
     }
 
     private WiresManager getWiresManager() {
@@ -170,7 +168,6 @@ public class ConnectorDragProxyImpl implements ConnectorDragProxy<AbstractCanvas
     private void deregisterTransientConnector() {
         if (null != this.connectorShapeView) {
             getWiresManager().deregister(connectorShapeView);
-            getCanvas().draw();
             this.connectorShapeView = null;
         }
     }
