@@ -28,17 +28,19 @@ import com.ait.lienzo.client.core.shape.wires.WiresConnection;
 import com.ait.lienzo.client.core.shape.wires.WiresLayoutContainer;
 import com.ait.lienzo.client.core.shape.wires.WiresMagnet;
 import com.ait.lienzo.client.core.shape.wires.WiresShape;
+import com.ait.lienzo.client.core.types.Shadow;
 import com.ait.tooling.nativetools.client.collection.NFastArrayList;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresUtils;
 import org.kie.workbench.common.stunner.client.lienzo.shape.view.LienzoShapeView;
+import org.kie.workbench.common.stunner.client.lienzo.util.ShapeViewUserDataEncoder;
 import org.kie.workbench.common.stunner.core.client.shape.view.BoundingBox;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasDragBounds;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 
-public class WiresShapeView<T> extends WiresShape
-        implements
-        LienzoShapeView<T>,
-        HasDragBounds<T> {
+public class WiresShapeView<T>
+        extends WiresShape
+        implements LienzoShapeView<T>,
+                   HasDragBounds<T> {
 
     private String uuid;
 
@@ -61,6 +63,7 @@ public class WiresShapeView<T> extends WiresShape
     @Override
     public T setUUID(final String uuid) {
         this.uuid = uuid;
+        ShapeViewUserDataEncoder.get().setShapeViewChildrenIds(uuid, getGroup());
         WiresUtils.assertShapeUUID(this.getGroup(),
                                    uuid);
         return cast();
@@ -275,4 +278,32 @@ public class WiresShapeView<T> extends WiresShape
     private T cast() {
         return (T) this;
     }
+
+    @Override
+    public T setShadow(final String color,
+                       final int blur,
+                       final double offx,
+                       final double offy) {
+        getShape().setShadow(new Shadow(color,
+                                        blur,
+                                        offx,
+                                        offx));
+        return cast();
+    }
+
+    @Override
+    public T removeShadow() {
+        getShape().setShadow(null);
+        return cast();
+    }
+
+    @Override
+    public Object getUserData() {
+        return getShape().getUserData();
+    }
+
+    @Override
+    public void setUserData(Object userData) {
+        getShape().setUserData(userData);
+    }
 }
