@@ -23,6 +23,7 @@ import com.ait.lienzo.client.core.shape.wires.IContainmentAcceptor;
 import com.ait.lienzo.client.core.shape.wires.IDockingAcceptor;
 import com.ait.lienzo.client.core.shape.wires.WiresConnection;
 import com.ait.lienzo.client.core.shape.wires.WiresMagnet;
+import com.ait.lienzo.client.core.types.Point2D;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
@@ -32,10 +33,12 @@ import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.command.SetConnectionSourceNodeCommand;
 import org.kie.workbench.common.stunner.core.client.canvas.command.SetConnectionTargetNodeCommand;
+import org.kie.workbench.common.stunner.core.client.canvas.event.CancelCanvasAction;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
+import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Edge;
@@ -47,12 +50,23 @@ import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
 import org.kie.workbench.common.stunner.core.graph.content.view.MagnetConnection;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
+import org.mockito.InOrder;
 import org.mockito.Mock;
+import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.inOrder;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class ConnectionAcceptorControlImplTest {
@@ -72,12 +86,15 @@ public class ConnectionAcceptorControlImplTest {
     @Mock
     private Node node;
     @Mock
-    private Edge<View<?>, Node> edge;
+    private Edge<ViewConnector<?>, Node> edge;
     @Mock
     private ViewConnector edgeContent;
     @Mock
     private Connection connection;
 
+    @Mock
+    private EventSourceMock<CancelCanvasAction> cancelCanvasActionEvent;
+
     private ConnectionAcceptorControlImpl tested;
     private SetConnectionSourceNodeCommand setConnectionSourceNodeCommand;
     private SetConnectionTargetNodeCommand setConnectionTargetNodeCommand;
@@ -124,13 +141,13 @@ public class ConnectionAcceptorControlImplTest {
                                   eq(setConnectionTargetNodeCommand))).thenReturn(result);
         when(commandManager.execute(eq(canvasHandler),
                                     eq(setConnectionTargetNodeCommand))).thenReturn(result);
-        this.tested = new ConnectionAcceptorControlImpl(canvasCommandFactory);
+        this.tested = new ConnectionAcceptorControlImpl(canvasCommandFactory, cancelCanvasActionEvent);
         this.tested.setCommandManagerProvider(() -> commandManager);
     }
 
     @Test
-    public void testEnable() {
-        tested.enable(canvasHandler);
+    public void testInit() {
+        tested.init(canvasHandler);
         assertEquals(canvasHandler,
                      tested.getCanvasHandler());
         verify(canvasView,
@@ -141,22 +158,9 @@ public class ConnectionAcceptorControlImplTest {
                never()).setContainmentAcceptor(any(IContainmentAcceptor.class));
     }
 
-    @Test
-    public void testDisable() {
-        tested.enable(canvasHandler);
-        tested.disable();
-        assertNull(tested.getCanvasHandler());
-        verify(canvasView,
-               times(1)).setConnectionAcceptor(eq(IConnectionAcceptor.NONE));
-        verify(canvasView,
-               never()).setDockingAcceptor(any(IDockingAcceptor.class));
-        verify(canvasView,
-               never()).setContainmentAcceptor(any(IContainmentAcceptor.class));
-    }
-
     @Test
     public void testAllowSource() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.allowSource(node,
                                                  edge,
                                                  connection);
@@ -179,7 +183,7 @@ public class ConnectionAcceptorControlImplTest {
     public void testSkipAllowSourceAsNoChanges() {
         when(edge.getSourceNode()).thenReturn(node);
         when(edgeContent.getSourceConnection()).thenReturn(Optional.of(connection));
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.allowSource(node,
                                                  edge,
                                                  connection);
@@ -194,7 +198,7 @@ public class ConnectionAcceptorControlImplTest {
 
     @Test
     public void testAllowTarget() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.allowTarget(node,
                                                  edge,
                                                  connection);
@@ -217,7 +221,7 @@ public class ConnectionAcceptorControlImplTest {
     public void testSkipAllowTargetAsNoChanges() {
         when(edge.getTargetNode()).thenReturn(node);
         when(edgeContent.getTargetConnection()).thenReturn(Optional.of(connection));
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.allowTarget(node,
                                                  edge,
                                                  connection);
@@ -232,7 +236,7 @@ public class ConnectionAcceptorControlImplTest {
 
     @Test
     public void testAcceptSource() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.acceptSource(node,
                                                   edge,
                                                   connection);
@@ -253,7 +257,7 @@ public class ConnectionAcceptorControlImplTest {
 
     @Test
     public void testAcceptTarget() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.acceptTarget(node,
                                                   edge,
                                                   connection);
@@ -275,7 +279,7 @@ public class ConnectionAcceptorControlImplTest {
     @Test
     public void testAcceptSourceAsNewConnection() {
         when(edge.getSourceNode()).thenReturn(node);
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.acceptSource(node,
                                                   edge,
                                                   connection);
@@ -297,7 +301,7 @@ public class ConnectionAcceptorControlImplTest {
     @Test
     public void testAcceptTargetNotNewConnection() {
         when(edge.getTargetNode()).thenReturn(node);
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean allow = tested.acceptTarget(node,
                                                   edge,
                                                   connection);
@@ -320,7 +324,7 @@ public class ConnectionAcceptorControlImplTest {
     public void testSkipAcceptSourceAsNoChanges() {
         when(edge.getSourceNode()).thenReturn(node);
         when(edgeContent.getSourceConnection()).thenReturn(Optional.of(connection));
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean accept = tested.acceptSource(node,
                                                    edge,
                                                    connection);
@@ -337,7 +341,7 @@ public class ConnectionAcceptorControlImplTest {
     public void testSkipAcceptTargetAsNoChanges() {
         when(edge.getTargetNode()).thenReturn(node);
         when(edgeContent.getTargetConnection()).thenReturn(Optional.of(connection));
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         final boolean accept = tested.acceptTarget(node,
                                                    edge,
                                                    connection);
@@ -381,8 +385,8 @@ public class ConnectionAcceptorControlImplTest {
         when(wiresMagnet.getY()).thenReturn(543d);
         when(wiresMagnet.getIndex()).thenReturn(7);
         MagnetConnection c2 =
-                ConnectionAcceptorControlImpl.createConnection(wiresConnection,
-                                                               wiresMagnet);
+                (MagnetConnection) ConnectionAcceptorControlImpl.createConnection(wiresConnection,
+                                                                                  wiresMagnet);
         assertEquals(122,
                      c2.getLocation().getX(),
                      0);
@@ -393,11 +397,29 @@ public class ConnectionAcceptorControlImplTest {
                      c2.getMagnetIndex().getAsInt());
         assertTrue(c2.isAuto());
 
+        // Asset connections to concrete locations, when no concrete magnets assigned.
+        when(wiresConnection.getPoint()).thenReturn(new Point2D(122d, 543d));
+        final Connection pointConnection = ConnectionAcceptorControlImpl.createConnection(wiresConnection, null);
+        assertEquals(122d, pointConnection.getLocation().getX(), 0);
+        assertEquals(543d, pointConnection.getLocation().getY(), 0);
+
         // Connections (view magnets) can be nullified.
         assertNull(ConnectionAcceptorControlImpl.createConnection(null));
-        assertNull(ConnectionAcceptorControlImpl.createConnection(wiresConnection,
-                                                                  null));
         assertNull(ConnectionAcceptorControlImpl.createConnection(null,
                                                                   null));
     }
+
+    @Test
+    public void onKeyDownEventTest() {
+        InOrder inOrder = inOrder(cancelCanvasActionEvent);
+
+        tested.init(canvasHandler);
+        tested.onKeyDownEvent(KeyboardEvent.Key.ESC);
+        tested.onKeyDownEvent(KeyboardEvent.Key.CONTROL);
+        tested.onKeyDownEvent(KeyboardEvent.Key.ARROW_RIGHT);
+
+        inOrder.verify(cancelCanvasActionEvent, times(1)).fire(any(CancelCanvasAction.class));
+        inOrder.verify(cancelCanvasActionEvent, never()).fire(any(CancelCanvasAction.class));
+        inOrder.verify(cancelCanvasActionEvent, never()).fire(any(CancelCanvasAction.class));
+    }
 }
