@@ -15,6 +15,8 @@
  */
 package org.kie.workbench.common.stunner.client.widgets.canvas.view;
 
+import java.util.Objects;
+
 import javax.annotation.PostConstruct;
 
 import com.ait.lienzo.client.core.shape.GridLayer;
@@ -22,6 +24,8 @@ import com.ait.lienzo.client.core.shape.Layer;
 import com.ait.lienzo.client.core.shape.Rectangle;
 import com.ait.lienzo.client.core.shape.wires.WiresContainer;
 import com.ait.lienzo.client.core.shape.wires.WiresShape;
+import com.ait.lienzo.client.core.shape.wires.handlers.WiresDockingControl;
+import com.ait.lienzo.client.core.types.Point2D;
 import com.ait.lienzo.shared.core.types.ColorName;
 import com.google.gwt.dom.client.Style;
 import com.google.gwt.user.client.ui.Composite;
@@ -38,11 +42,12 @@ public class CanvasView extends Composite implements AbstractCanvas.View<com.ait
     public static final String CURSOR_NOT_ALLOWED = "not-allowed";
     private static final String Bg_COLOR = "#FFFFFF";
 
-    protected FlowPanel mainPanel = new FlowPanel();
-    protected FlowPanel toolsPanel = new FlowPanel();
-    protected com.ait.lienzo.client.widget.LienzoPanel panel;
-    protected Layer canvasLayer = new Layer();
-    protected org.kie.workbench.common.stunner.core.client.canvas.Layer layer;
+    private final FlowPanel mainPanel = new FlowPanel();
+    private final FlowPanel toolsPanel = new FlowPanel();
+    private final Layer canvasLayer = new Layer();
+    private com.ait.lienzo.client.widget.LienzoPanel panel;
+    private org.kie.workbench.common.stunner.core.client.canvas.Layer layer;
+
     /**
      * Defines the usable area in the layer by stroking a rectangle for the
      * defined canvas size. It provides visual feedback about the diagram's
@@ -151,8 +156,11 @@ public class CanvasView extends Composite implements AbstractCanvas.View<com.ait
 
     AbstractCanvas.View dockShape(final WiresContainer parentShape,
                                   final WiresShape childShape) {
-        parentShape.add(childShape);
-        childShape.setDockedTo(parentShape);
+        WiresDockingControl dockingControl = childShape.getControl().getDockingControl();
+        Point2D dockLocation = (Objects.isNull(dockingControl.getCandidateLocation()) ?
+                childShape.getLocation() :
+                dockingControl.getCandidateLocation());
+        dockingControl.dock(childShape, parentShape, dockLocation);
         return this;
     }
 
@@ -167,8 +175,10 @@ public class CanvasView extends Composite implements AbstractCanvas.View<com.ait
 
     AbstractCanvas.View undock(final WiresShape targetShape,
                                final WiresShape childShape) {
-        targetShape.remove(childShape);
-        childShape.setDockedTo(null);
+
+        childShape.getControl()
+                .getDockingControl()
+                .undock(childShape, targetShape);
         return this;
     }
 
@@ -255,6 +265,10 @@ public class CanvasView extends Composite implements AbstractCanvas.View<com.ait
         return layer;
     }
 
+    protected Layer getCanvasLayer() {
+        return canvasLayer;
+    }
+
     @Override
     public AbstractCanvas.View clear() {
         layer.clear();
@@ -268,12 +282,10 @@ public class CanvasView extends Composite implements AbstractCanvas.View<com.ait
         this.toolsPanel.clear();
         this.layer.destroy();
         this.canvasLayer.removeFromParent();
-        this.panel.removeFromParent();
-        this.mainPanel = null;
-        this.toolsPanel = null;
-        this.panel = null;
         this.layer = null;
-        this.canvasLayer = null;
+        this.panel.removeAll();
+        this.panel.removeFromParent();
+        this.panel = null;
     }
 }
 
