@@ -43,17 +43,19 @@ import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 @Default
 public class WiresCanvasView extends CanvasView implements WiresCanvas.View {
 
+    private final WiresManagerFactory wiresManagerFactory;
+
     protected WiresManager wiresManager;
-    private WiresManagerFactory wiresManagerFactory;
 
     @Inject
     public WiresCanvasView(@Default WiresManagerFactory wiresManagerFactory) {
         this.wiresManagerFactory = wiresManagerFactory;
     }
 
+    @Override
     public void init() {
         super.init();
-        wiresManager = wiresManagerFactory.newWiresManager(canvasLayer);
+        wiresManager = wiresManagerFactory.newWiresManager(getCanvasLayer());
         wiresManager.setSpliceEnabled(false);
     }
 
@@ -112,6 +114,13 @@ public class WiresCanvasView extends CanvasView implements WiresCanvas.View {
         return this;
     }
 
+    @Override
+    public void destroy() {
+        WiresManager.remove(wiresManager);
+        wiresManager = null;
+        super.destroy();
+    }
+
     @Override
     public WiresManager getWiresManager() {
         return wiresManager;
@@ -119,7 +128,7 @@ public class WiresCanvasView extends CanvasView implements WiresCanvas.View {
 
     @Override
     public Layer getTopLayer() {
-        return canvasLayer.getScene().getTopLayer();
+        return getCanvasLayer().getScene().getTopLayer();
     }
 
     protected Direction[] getMagnetCardinals() {
