@@ -24,6 +24,7 @@ import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandResultBuilder;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
+import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
@@ -33,7 +34,8 @@ import org.mockito.Mock;
 import org.uberfire.mvp.ParameterizedCommand;
 
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.when;
 
 public abstract class AbstractCanvasHandlerViewerTest {
 
@@ -55,6 +57,8 @@ public abstract class AbstractCanvasHandlerViewerTest {
     @Mock
     protected Diagram diagram;
     @Mock
+    protected Metadata metadata;
+    @Mock
     protected Graph graph;
     @Mock
     protected DefinitionSet graphContent;
@@ -91,6 +95,7 @@ public abstract class AbstractCanvasHandlerViewerTest {
             when(canvasHandler.getDiagram()).thenReturn(canvasHandlerDiagram);
             return null;
         }).when(canvasHandler).destroy();
+        when(diagram.getMetadata()).thenReturn(metadata);
         when(diagram.getGraph()).thenReturn(graph);
         when(graph.getContent()).thenReturn(graphContent);
         when(graphContent.getBounds()).thenReturn(GRAPH_BOUNDS);
