@@ -20,14 +20,14 @@ import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 
 /**
  * A Shape type provides the bride between the canvas handler and the shape view.
- * <p/>
+ * <p>
  * It should not contain any specific view code, so this way the same Shape can handle different views.
  * This type of shape is not mutable by default, so the shape attributes are not changed as per
  * model updates. Once it gets rendered, it will not change anymore, rather than
  * if any of the ShapeStates has some visual feedback.
  * @param <V> The Shape View type.
  */
-public interface Shape<V extends ShapeView> {
+public interface Shape<V extends ShapeView> extends HasShapeState {
 
     /**
      * Sets a unique identifier for the shape in a canvas.
@@ -39,11 +39,6 @@ public interface Shape<V extends ShapeView> {
      */
     String getUUID();
 
-    /**
-     * Update shape's view state.
-     */
-    void applyState(final ShapeState shapeState);
-
     /**
      * Returns the view representation on the canvas for the shape.
      */
