@@ -19,15 +19,18 @@ package org.kie.workbench.common.stunner.core.client.session.command.impl;
 import java.util.logging.Logger;
 
 import javax.enterprise.context.Dependent;
+import javax.enterprise.event.Event;
+import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.CanvasViolation;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
-import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
 import org.kie.workbench.common.stunner.core.client.session.Session;
 import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.command.CommandResult;
 import org.kie.workbench.common.stunner.core.command.util.CommandUtils;
 
@@ -40,31 +43,41 @@ import static org.kie.soup.commons.validation.PortablePreconditions.checkNotNull
  * after a successful execution.
  */
 @Dependent
-public class ClearSessionCommand extends AbstractClientSessionCommand<ClientFullSession> {
+@Default
+public class ClearSessionCommand extends AbstractClientSessionCommand<EditorSession> {
 
     private static Logger LOGGER = Logger.getLogger(ClearSessionCommand.class.getName());
 
     private final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
     private final SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
+    private final Event<ClearSessionCommandExecutedEvent> commandExecutedEvent;
 
     protected ClearSessionCommand() {
         this(null,
+             null,
              null);
     }
 
     @Inject
     public ClearSessionCommand(final CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory,
-                               final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager) {
+                               final @Session SessionCommandManager<AbstractCanvasHandler> sessionCommandManager,
+                               final Event<ClearSessionCommandExecutedEvent> commandExecutedEvent) {
         super(true);
         this.canvasCommandFactory = canvasCommandFactory;
         this.sessionCommandManager = sessionCommandManager;
+        this.commandExecutedEvent = commandExecutedEvent;
     }
 
     @Override
-    public void bind(final ClientFullSession session) {
+    public void bind(final EditorSession session) {
         super.bind(session);
     }
 
+    @Override
+    public boolean accepts(final ClientSession session) {
+        return session instanceof EditorSession;
+    }
+
     @Override
     @SuppressWarnings("unchecked")
     public <V> void execute(final Callback<V> callback) {
@@ -76,6 +89,8 @@ public class ClearSessionCommand extends AbstractClientSessionCommand<ClientFull
                          canvasCommandFactory.clearCanvas());
         if (!CommandUtils.isError(result)) {
             cleanSessionRegistry();
+            commandExecutedEvent.fire(new ClearSessionCommandExecutedEvent(this,
+                                                                           getSession()));
             callback.onSuccess();
         } else {
             callback.onError((V) result);
