@@ -55,10 +55,19 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.ParameterizedCommand;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.anyDouble;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class BaseCanvasHandlerTest {
@@ -172,8 +181,6 @@ public class BaseCanvasHandlerTest {
                         false);
         verify(canvas,
                times(1)).addShape(eq(shape));
-        verify(canvas,
-               times(1)).draw();
     }
 
     @Test
@@ -184,8 +191,6 @@ public class BaseCanvasHandlerTest {
                           false);
         verify(canvas,
                times(1)).deleteShape(eq(shape));
-        verify(canvas,
-               times(1)).draw();
     }
 
     @Test
@@ -219,8 +224,6 @@ public class BaseCanvasHandlerTest {
         verify(shape,
                times(1)).applyProperties(eq(candidate),
                                          eq(mutationContext));
-        verify(canvas,
-               times(1)).draw();
     }
 
     @Test
