@@ -24,8 +24,9 @@ import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class SetConnectionSourceNodeCommandTest extends AbstractCanvasCommandTest {
@@ -41,8 +42,8 @@ public class SetConnectionSourceNodeCommandTest extends AbstractCanvasCommandTes
 
     @Before
     @SuppressWarnings("unchecked")
-    public void setup() throws Exception {
-        super.setup();
+    public void setUp() throws Exception {
+        super.setUp();
         when(edge.getUUID()).thenReturn("e1");
         when(node.getUUID()).thenReturn("n1");
         this.tested = new SetConnectionSourceNodeCommand(node,
