@@ -19,12 +19,12 @@ package org.kie.workbench.common.stunner.core.client.command;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.stunner.core.client.api.AbstractClientSessionManager;
+import org.kie.workbench.common.stunner.core.client.api.SessionManager;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.event.mouse.CanvasMouseDownEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.mouse.CanvasMouseUpEvent;
-import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.command.Command;
 import org.kie.workbench.common.stunner.core.command.impl.CompositeCommand;
 import org.kie.workbench.common.stunner.core.registry.command.CommandRegistry;
@@ -50,13 +50,13 @@ import static org.mockito.Mockito.when;
 public class RequestCommandManagerTest {
 
     @Mock
-    AbstractClientSessionManager clientSessionManager;
+    SessionManager clientSessionManager;
     @Mock
     AbstractCanvasHandler canvasHandler;
     @Mock
     AbstractCanvas canvas;
     @Mock
-    ClientFullSession clientFullSession;
+    EditorSession editorSession;
     @Mock
     Command<AbstractCanvasHandler, CanvasViolation> command;
     @Mock
@@ -71,16 +71,15 @@ public class RequestCommandManagerTest {
     CanvasMouseUpEvent mouseUpEvent;
 
     private RequestCommandManager tested;
-    private CanvasCommandManagerImpl commandManager;
 
     @Before
     public void setup() throws Exception {
-        this.commandManager = new CanvasCommandManagerImpl();
+        CanvasCommandManagerImpl commandManager = new CanvasCommandManagerImpl();
         when(canvasHandler.getCanvas()).thenReturn(canvas);
-        when(clientSessionManager.getCurrentSession()).thenReturn(clientFullSession);
-        when(clientFullSession.getCanvasHandler()).thenReturn(canvasHandler);
-        when(clientFullSession.getCommandRegistry()).thenReturn(commandRegistry);
-        when(clientFullSession.getCommandManager()).thenReturn(commandManager);
+        when(clientSessionManager.getCurrentSession()).thenReturn(editorSession);
+        when(editorSession.getCanvasHandler()).thenReturn(canvasHandler);
+        when(editorSession.getCommandRegistry()).thenReturn(commandRegistry);
+        when(editorSession.getCommandManager()).thenReturn(commandManager);
         this.tested = new RequestCommandManager(clientSessionManager);
     }
 
@@ -202,7 +201,7 @@ public class RequestCommandManagerTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    public void testNoRequestComleted() {
+    public void testNoRequestCompleted() {
         when(command.execute(eq(canvasHandler))).thenReturn(CanvasCommandResultBuilder.SUCCESS);
         tested.onCanvasMouseDownEvent(mouseDownEvent);
         tested.execute(canvasHandler,
