@@ -23,11 +23,13 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.Layer;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasClearSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommand;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
 import org.kie.workbench.common.stunner.core.client.command.SessionCommandManager;
 import org.kie.workbench.common.stunner.core.client.i18n.ClientTranslationService;
+import org.kie.workbench.common.stunner.core.client.shape.factory.ShapeFactory;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseClickEvent;
 import org.kie.workbench.common.stunner.core.definition.morph.MorphDefinition;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
@@ -64,12 +66,18 @@ public class MorphNodeActionTest {
     @Mock
     private SessionCommandManager<AbstractCanvasHandler> sessionCommandManager;
 
+    @Mock
+    private ShapeFactory shapeFactory;
+
     @Mock
     private CanvasCommandFactory<AbstractCanvasHandler> commandFactory;
 
     @Mock
     private EventSourceMock<CanvasSelectionEvent> canvasElementSelectedEvent;
 
+    @Mock
+    private EventSourceMock<CanvasClearSelectionEvent> canvasClearSelectionEventEventSourceMock;
+
     @Mock
     private AbstractCanvasHandler canvasHandler;
 
@@ -110,6 +118,7 @@ public class MorphNodeActionTest {
         when(canvasHandler.getGraphIndex()).thenReturn(graphIndex);
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(canvasHandler.getCanvas()).thenReturn(canvas);
+        when(canvasHandler.getShapeFactory(eq(SSID_UUID))).thenReturn(shapeFactory);
         when(canvas.getLayer()).thenReturn(layer);
         when(diagram.getMetadata()).thenReturn(metadata);
         when(metadata.getShapeSetId()).thenReturn(SSID_UUID);
@@ -119,9 +128,11 @@ public class MorphNodeActionTest {
                                           sessionCommandManager,
                                           commandFactory,
                                           translationService,
-                                          canvasElementSelectedEvent)
+                                          canvasElementSelectedEvent,
+                                          canvasClearSelectionEventEventSourceMock)
                 .setMorphDefinition(morphDefinition)
                 .setTargetDefinitionId(MORPH_TARGET_ID);
+        tested.commandDelay = 0;
     }
 
     @Test
@@ -132,6 +143,19 @@ public class MorphNodeActionTest {
                times(1)).getValue(eq(MorphNodeAction.KEY_TITLE));
     }
 
+    @Test
+    public void testGlyph() {
+        assertEquals(MORPH_TARGET_ID,
+                     tested.getGlyphId(canvasHandler,
+                                       E_UUID));
+
+        tested.getGlyph(canvasHandler,
+                        E_UUID);
+
+        verify(shapeFactory).getGlyph(MORPH_TARGET_ID,
+                                      AbstractToolboxAction.ToolboxGlyphConsumer.class);
+    }
+
     @Test
     public void testAction() {
         final MouseClickEvent event = mock(MouseClickEvent.class);
