@@ -21,8 +21,8 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.mockito.Mockito.verify;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ClientBindableDefinitionSetAdapterTest extends AbstractClientBindableAdapterTest {
@@ -38,7 +38,7 @@ public class ClientBindableDefinitionSetAdapterTest extends AbstractClientBindab
     }
 
     @Test
-    public void testFunctionallity() {
+    public void testFunctionality() {
         String description = clientBindableDefinitionSetAdapter.getDescription(model);
 
         verify(translationService).getDefinitionSetDescription(model.getClass().getName());
