@@ -16,18 +16,12 @@
 
 package org.kie.workbench.common.stunner.core.client.session.command.impl;
 
+import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.util.CanvasFileExport;
-import org.kie.workbench.common.stunner.core.client.session.command.ClientSessionCommand;
-import org.kie.workbench.common.stunner.core.client.session.impl.AbstractClientSession;
-import org.kie.workbench.common.stunner.core.diagram.Diagram;
-import org.kie.workbench.common.stunner.core.diagram.Metadata;
-import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
-import org.uberfire.backend.vfs.Path;
+import org.kie.workbench.common.stunner.core.client.session.command.AbstractClientSessionCommand;
 
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
@@ -35,50 +29,25 @@ import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
-public class ExportToPngSessionCommandTest {
-
-    private static final String FILE_NAME = "file-name1";
-
-    @Mock
-    private CanvasFileExport canvasFileExport;
-
-    @Mock
-    private AbstractClientSession session;
-
-    @Mock
-    private AbstractCanvasHandler canvasHandler;
-
-    @Mock
-    private Diagram diagram;
-
-    @Mock
-    private Metadata metadata;
-
-    @Mock
-    private Path path;
-
-    @Mock
-    private ClientSessionCommand.Callback callback;
+@RunWith(GwtMockitoTestRunner.class)
+public class ExportToPngSessionCommandTest extends AbstractExportSessionCommandTest {
 
     private ExportToPngSessionCommand tested;
 
     @Before
-    public void setup() throws Exception {
-        when(session.getCanvasHandler()).thenReturn(canvasHandler);
-        when(canvasHandler.getDiagram()).thenReturn(diagram);
-        when(diagram.getMetadata()).thenReturn(metadata);
-        when(metadata.getPath()).thenReturn(path);
-        when(path.getFileName()).thenReturn(FILE_NAME);
+    public void setup() {
+        super.setup();
         this.tested = new ExportToPngSessionCommand(canvasFileExport);
         this.tested.bind(session);
+        setTimer(this.tested);
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void testExport() {
         this.tested.execute(callback);
+
         verify(canvasFileExport,
                times(1)).exportToPng(eq(canvasHandler),
                                      eq(FILE_NAME));
@@ -89,4 +58,9 @@ public class ExportToPngSessionCommandTest {
                never()).exportToPdf(any(AbstractCanvasHandler.class),
                                     anyString());
     }
+
+    @Override
+    protected AbstractClientSessionCommand getCommand() {
+        return tested;
+    }
 }
