@@ -54,6 +54,7 @@ import org.kie.workbench.common.stunner.core.definition.builder.VoidBuilder;
 import org.kie.workbench.common.stunner.core.definition.property.PropertyMetaTypes;
 import org.kie.workbench.common.stunner.core.definition.property.PropertyType;
 import org.kie.workbench.common.stunner.core.processors.definition.BindableDefinitionAdapterGenerator;
+import org.kie.workbench.common.stunner.core.processors.definition.TypeConstructor;
 import org.kie.workbench.common.stunner.core.processors.definitionset.BindableDefinitionSetAdapterGenerator;
 import org.kie.workbench.common.stunner.core.processors.definitionset.DefinitionSetProxyGenerator;
 import org.kie.workbench.common.stunner.core.processors.factory.ModelFactoryGenerator;
@@ -98,12 +99,15 @@ public class MainProcessor extends AbstractErrorAbsorbingProcessor {
     public static final String ANNOTATION_DEFINITION_SET = "org.kie.workbench.common.stunner.core.definition.annotation.DefinitionSet";
 
     public static final String ANNOTATION_DEFINITION = "org.kie.workbench.common.stunner.core.definition.annotation.Definition";
+    public static final String ANNOTATION_DEFINITION_ID = "org.kie.workbench.common.stunner.core.definition.annotation.definition.Id";
     public static final String ANNOTATION_DEFINITION_CATEGORY = "org.kie.workbench.common.stunner.core.definition.annotation.definition.Category";
     public static final String ANNOTATION_DEFINITION_LABELS = "org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels";
     public static final String ANNOTATION_DEFINITION_TITLE = "org.kie.workbench.common.stunner.core.definition.annotation.definition.Title";
 
     public static final String[] DEFINITION_ANNOTATIONS = new String[]{
-            ANNOTATION_DEFINITION_CATEGORY, ANNOTATION_DEFINITION_LABELS,
+            ANNOTATION_DEFINITION_ID,
+            ANNOTATION_DEFINITION_CATEGORY,
+            ANNOTATION_DEFINITION_LABELS,
             ANNOTATION_DEFINITION_TITLE
     };
 
@@ -425,25 +429,31 @@ public class MainProcessor extends AbstractErrorAbsorbingProcessor {
                 baseTypes.put(defintionClassName,
                               baseClassName);
             }
-            // Category fields.
+            // Id field.
+            processFieldName(classElement,
+                             defintionClassName,
+                             ANNOTATION_DEFINITION_ID,
+                             processingContext.getDefinitionAnnotations().getIdFieldNames(),
+                             false);
+            // Category field.
             processFieldName(classElement,
                              defintionClassName,
                              ANNOTATION_DEFINITION_CATEGORY,
                              processingContext.getDefinitionAnnotations().getCategoryFieldNames(),
                              true);
-            // Title fields.
+            // Title field.
             processFieldName(classElement,
                              defintionClassName,
                              ANNOTATION_DEFINITION_TITLE,
                              processingContext.getDefinitionAnnotations().getTitleFieldNames(),
                              false);
-            // Description fields.
+            // Description field.
             processFieldName(classElement,
                              defintionClassName,
                              ANNOTATION_DESCRIPTION,
                              processingContext.getDefinitionAnnotations().getDescriptionFieldNames(),
                              false);
-            // Labels fields.
+            // Labels field.
             processFieldName(classElement,
                              defintionClassName,
                              ANNOTATION_DEFINITION_LABELS,
@@ -654,7 +664,7 @@ public class MainProcessor extends AbstractErrorAbsorbingProcessor {
 
     private void processDefinitionModelBuilder(final Element e,
                                                final String className,
-                                               final Map<String, String> processingContextMap) {
+                                               final Map<String, TypeConstructor> processingContextMap) {
         Definition definitionAnn = e.getAnnotation(Definition.class);
         TypeMirror bMirror = null;
         try {
@@ -665,13 +675,16 @@ public class MainProcessor extends AbstractErrorAbsorbingProcessor {
         if (null != bMirror && !VoidBuilder.class.getName().equals(bMirror.toString())) {
             String fqcn = bMirror.toString();
             processingContextMap.put(className,
-                                     fqcn);
+                                     TypeConstructor.builder(fqcn));
+        } else {
+            processingContextMap.put(className,
+                                     TypeConstructor.constructor(className));
         }
     }
 
     private void processDefinitionSetModelBuilder(final Element e,
                                                   final String className,
-                                                  final Map<String, String> processingContextMap) {
+                                                  final Map<String, TypeConstructor> processingContextMap) {
         DefinitionSet definitionAnn = e.getAnnotation(DefinitionSet.class);
         TypeMirror bMirror = null;
         try {
@@ -682,7 +695,7 @@ public class MainProcessor extends AbstractErrorAbsorbingProcessor {
         if (null != bMirror && !VoidBuilder.class.getName().equals(bMirror.toString())) {
             String fqcn = bMirror.toString();
             processingContextMap.put(className,
-                                     fqcn);
+                                     TypeConstructor.builder(fqcn));
         }
     }
 
@@ -1211,10 +1224,12 @@ public class MainProcessor extends AbstractErrorAbsorbingProcessor {
             if (size > 0) {
                 final Map<String, String> buildersMap = new LinkedHashMap<>();
                 if (!processingContext.getDefinitionAnnotations().getBuilderFieldNames().isEmpty()) {
-                    buildersMap.putAll(processingContext.getDefinitionAnnotations().getBuilderFieldNames());
+                    processingContext.getDefinitionAnnotations().getBuilderFieldNames().forEach(
+                            (key, value) -> buildersMap.put(key, value.toCode()));
                 }
                 if (!processingContext.getDefSetAnnotations().getBuilderFieldNames().isEmpty()) {
-                    buildersMap.putAll(processingContext.getDefSetAnnotations().getBuilderFieldNames());
+                    processingContext.getDefSetAnnotations().getBuilderFieldNames().forEach(
+                            (key, value) -> buildersMap.put(key, value.toCode()));
                 }
                 // Ensure visible on both backend and client sides.
                 final String packageName = getGeneratedPackageName() + ".definition.factory";
