@@ -19,6 +19,7 @@ package org.kie.workbench.common.stunner.core.processors.definition;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.Map;
+
 import javax.annotation.processing.Messager;
 
 import org.kie.workbench.common.stunner.core.definition.adapter.binding.BindableAdapterFactory;
@@ -55,6 +56,9 @@ public class BindableDefinitionAdapterGenerator extends AbstractBindableAdapterG
         addFields("baseTypes",
                   root,
                   processingDefinitionAnnotations.getBaseTypes());
+        addFields("idFieldNames",
+                  root,
+                  processingDefinitionAnnotations.getIdFieldNames());
         addFields("categoryFieldNames",
                   root,
                   processingDefinitionAnnotations.getCategoryFieldNames());
