@@ -77,6 +77,7 @@ public abstract class BaseCatchingIntermediateEvent
 
     protected void initLabels() {
         labels.add("all");
+        labels.add("lane_child");
         labels.add("sequence_start");
         labels.add("sequence_end");
         labels.add("to_task_event");
@@ -88,6 +89,7 @@ public abstract class BaseCatchingIntermediateEvent
         labels.add("EventOnChoreographyActivityBoundary");
         labels.add("IntermediateEventsMorph");
         labels.add("cm_nop");
+        labels.add("IntermediateEventCatching");
     }
 
     @Override
