@@ -19,19 +19,25 @@ package org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.pro
 import bpsim.ElementParameters;
 import org.eclipse.bpmn2.CatchEvent;
 import org.eclipse.bpmn2.EventDefinition;
+import org.eclipse.bpmn2.OutputSet;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.customproperties.ParsedAssignmentsInfo;
 import org.kie.workbench.common.stunner.bpmn.backend.converters.tostunner.properties.SimulationAttributeSets;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.AssignmentsInfo;
 import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.SimulationAttributeSet;
 
+import static org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.Factories.bpmn2;
+
 public class CatchEventPropertyWriter extends EventPropertyWriter {
 
     private final CatchEvent event;
+    private final OutputSet outputSet;
     private ElementParameters simulationParameters;
 
     public CatchEventPropertyWriter(CatchEvent event, VariableScope variableScope) {
         super(event, variableScope);
         this.event = event;
+        this.outputSet = bpmn2.createOutputSet();
+        event.setOutputSet(outputSet);
     }
 
     public void setAssignmentsInfo(AssignmentsInfo info) {
@@ -49,8 +55,8 @@ public class CatchEventPropertyWriter extends EventPropertyWriter {
                 .forEach(doa -> {
                     this.addItemDefinition(doa.getItemDefinition());
                     event.getDataOutputs().add(doa.getDataOutput());
-                    event.setOutputSet(doa.getOutputSet());
                     event.getDataOutputAssociation().add(doa.getAssociation());
+                    outputSet.getDataOutputRefs().add(doa.getDataOutput());
                 });
     }
 
