@@ -32,10 +32,12 @@ import java.util.Set;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
+import org.eclipse.bpmn2.Definitions;
 import org.kie.workbench.common.stunner.backend.definition.factory.TestScopeModelFactory;
 import org.kie.workbench.common.stunner.bpmn.BPMNDefinitionSet;
 import org.kie.workbench.common.stunner.bpmn.backend.BPMNDiagramMarshaller;
 import org.kie.workbench.common.stunner.bpmn.backend.BPMNDirectDiagramMarshaller;
+import org.kie.workbench.common.stunner.bpmn.backend.converters.fromstunner.DefinitionsConverter;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.builder.BPMNGraphObjectBuilderFactory;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.Bpmn2OryxIdMappings;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.Bpmn2OryxManager;
@@ -50,13 +52,14 @@ import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.ScriptTypeListTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.ScriptTypeTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.StringTypeSerializer;
+import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.TaskTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.TimerSettingsTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.marshall.json.oryx.property.VariablesTypeSerializer;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.MockApplicationFactoryManager;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.TaskTypeMorphDefinition;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.Unmarshalling;
 import org.kie.workbench.common.stunner.bpmn.backend.service.diagram.WorkItemDefinitionMockRegistry;
-import org.kie.workbench.common.stunner.bpmn.backend.workitem.WorkItemDefinitionBackendRegistry;
+import org.kie.workbench.common.stunner.bpmn.backend.workitem.service.WorkItemDefinitionBackendService;
 import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
 import org.kie.workbench.common.stunner.bpmn.definition.NoneTask;
 import org.kie.workbench.common.stunner.bpmn.definition.ScriptTask;
@@ -159,7 +162,8 @@ public abstract class BPMNDiagramMarshallerBase {
         when(definitionManager.adapters()).thenReturn(adapterManager);
         when(adapterManager.registry()).thenReturn(adapterRegistry);
         DefinitionUtils definitionUtils1 = new DefinitionUtils(definitionManager,
-                                                               applicationFactoryManager);
+                                                               applicationFactoryManager,
+                                                               null); // TODO!
         testScopeModelFactory = new TestScopeModelFactory(new BPMNDefinitionSet.BPMNDefinitionSetBuilder().build());
         // Definition manager.
         final BackendDefinitionAdapter definitionAdapter = new BackendDefinitionAdapter(definitionUtils1);
@@ -248,6 +252,8 @@ public abstract class BPMNDiagramMarshallerBase {
         TimerSettingsTypeSerializer timerSettingsTypeSerializer = new TimerSettingsTypeSerializer();
         ScriptTypeTypeSerializer scriptTypeTypeSerializer = new ScriptTypeTypeSerializer();
         ScriptTypeListTypeSerializer scriptTypeListTypeSerializer = new ScriptTypeListTypeSerializer();
+        TaskTypeSerializer taskTypeSerializer = new TaskTypeSerializer(definitionUtils1,
+                                                                       enumTypeSerializer);
         List<Bpmn2OryxPropertySerializer<?>> propertySerializers = new LinkedList<>();
         propertySerializers.add(stringTypeSerializer);
         propertySerializers.add(booleanTypeSerializer);
@@ -260,6 +266,7 @@ public abstract class BPMNDiagramMarshallerBase {
         propertySerializers.add(timerSettingsTypeSerializer);
         propertySerializers.add(scriptTypeTypeSerializer);
         propertySerializers.add(scriptTypeListTypeSerializer);
+        propertySerializers.add(taskTypeSerializer);
         Bpmn2OryxPropertyManager oryxPropertyManager = new Bpmn2OryxPropertyManager(propertySerializers);
         Bpmn2OryxManager oryxManager = new Bpmn2OryxManager(oryxIdMappings,
                                                             oryxPropertyManager);
@@ -284,13 +291,9 @@ public abstract class BPMNDiagramMarshallerBase {
         GraphIndexBuilder<?> indexBuilder = new MapIndexBuilder();
         when(rulesManager.evaluate(any(RuleSet.class),
                                    any(RuleEvaluationContext.class))).thenReturn(new DefaultRuleViolations());
-        // The work item definition registry.
-        WorkItemDefinitionBackendRegistry widRegistry = mock(WorkItemDefinitionBackendRegistry.class);
-        when(widRegistry.getRegistry()).thenReturn(workItemDefinitionMockRegistry);
-        when(widRegistry.items()).thenReturn(workItemDefinitionMockRegistry.items());
-        when(widRegistry.load(any(Metadata.class))).thenReturn(widRegistry);
-        doAnswer(invocationOnMock -> workItemDefinitionMockRegistry.get((String) invocationOnMock.getArguments()[0]))
-                .when(widRegistry).get(anyString());
+        // The work item definition service.
+        WorkItemDefinitionBackendService widService = mock(WorkItemDefinitionBackendService.class);
+        when(widService.execute(any(Metadata.class))).thenReturn(workItemDefinitionMockRegistry.items());
         // The tested BPMN marshaller.
         oldMarshaller = new BPMNDiagramMarshaller(new XMLEncoderDiagramMetadataMarshaller(),
                                                   objectBuilderFactory,
@@ -298,10 +301,11 @@ public abstract class BPMNDiagramMarshallerBase {
                                                   indexBuilder,
                                                   oryxManager,
                                                   applicationFactoryManager,
+                                                  null, // TODO!
                                                   rulesManager,
                                                   commandManager1,
                                                   commandFactory1,
-                                                  widRegistry);
+                                                  widService);
 
         // Graph utils.
         when(definitionManager.adapters()).thenReturn(adapterManager);
@@ -311,7 +315,8 @@ public abstract class BPMNDiagramMarshallerBase {
                                    any(RuleEvaluationContext.class))).thenReturn(new DefaultRuleViolations());
 
         DefinitionUtils definitionUtils = new DefinitionUtils(definitionManager,
-                                                              applicationFactoryManager);
+                                                              applicationFactoryManager,
+                                                              null); // TODO!
         TestScopeModelFactory testScopeModelFactory = new TestScopeModelFactory(new BPMNDefinitionSet.BPMNDefinitionSetBuilder().build());
         // Definition manager.
         mockAdapterManager(definitionAdapter, definitionSetAdapter, propertySetAdapter, propertyAdapter);
@@ -334,6 +339,7 @@ public abstract class BPMNDiagramMarshallerBase {
                 new XMLEncoderDiagramMetadataMarshaller(),
                 definitionManager,
                 rulesManager,
+                widService,
                 applicationFactoryManager,
                 commandFactory,
                 commandManager);
@@ -377,6 +383,11 @@ public abstract class BPMNDiagramMarshallerBase {
         return Unmarshalling.unmarshall(marshaller, is);
     }
 
+    protected Definitions convertToDefinitions(Diagram<Graph, Metadata> d) {
+        return new DefinitionsConverter(d.getGraph())
+                .toDefinitions();
+    }
+
     protected InputStream getStream(String data) {
         return new ByteArrayInputStream(data.getBytes(StandardCharsets.UTF_8));
     }
