@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.bpmn.client.forms.fields.assignmentsEdi
 
 import java.io.IOException;
 import java.util.Set;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -343,6 +344,14 @@ public class AssignmentListItemWidgetViewImpl extends Composite implements Assig
         return parentWidget.isDuplicateName(name);
     }
 
+    @Override
+    public void setReadOnly(final boolean readOnly) {
+        name.setReadOnly(readOnly);
+        dataType.setEnabled(!readOnly);
+        processVar.setEnabled(!readOnly);
+        deleteButton.setEnabled(!readOnly);
+    }
+
     @EventHandler("deleteButton")
     public void handleDeleteButton(final ClickEvent e) {
         parentWidget.removeAssignment(getModel());
