@@ -35,6 +35,8 @@ public interface BPMNSVGViewFactory {
     String PATH_LANE = "images/shapes/lane.svg";
     String PATH_SUBPROCESS = "images/shapes/subprocess.svg";
     String PATH_SUBPROCESS_ADHOC = "images/shapes/subprocess-adhoc.svg";
+    String PATH_SUBPROCESS_EVENT = "images/shapes/subprocess-event.svg";
+    String PATH_SUBPROCESS_MULTIPLE_INSTANCE = "images/shapes/subprocess-multiple-instance.svg";
     String PATH_RECTANGLE = "images/shapes/rectangle.svg";
 
     @SVGSource(PATH_TASK)
@@ -49,12 +51,18 @@ public interface BPMNSVGViewFactory {
     @SVGSource(PATH_TASK)
     SVGShapeViewResource businessRuleTask();
 
+    @SVGSource(PATH_TASK)
+    SVGShapeViewResource serviceTask();
+
     @SVGSource(PATH_GATEWAY)
     SVGShapeViewResource parallelMultipleGateway();
 
     @SVGSource(PATH_GATEWAY)
     SVGShapeViewResource exclusiveGateway();
 
+    @SVGSource(PATH_GATEWAY)
+    SVGShapeViewResource inclusiveGateway();
+
     @SVGSource(PATH_EVENT_ALL)
     SVGShapeViewResource startNoneEvent();
 
@@ -115,9 +123,15 @@ public interface BPMNSVGViewFactory {
     @SVGSource(PATH_SUBPROCESS_ADHOC)
     SVGShapeViewResource adHocSubProcess();
 
+    @SVGSource(PATH_SUBPROCESS_MULTIPLE_INSTANCE)
+    SVGShapeViewResource multipleInstanceSubProcess();
+
     @SVGSource(PATH_SUBPROCESS_ADHOC)
     SVGShapeViewResource embeddedSubProcess();
 
+    @SVGSource(PATH_SUBPROCESS_EVENT)
+    SVGShapeViewResource eventSubProcess();
+
     @SVGSource(PATH_RECTANGLE)
     SVGShapeViewResource rectangle();
 }
