@@ -20,7 +20,7 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.function.BiConsumer;
 
-import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNSVGGlyphFactory;
+import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNGlyphFactory;
 import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNSVGViewFactory;
 import org.kie.workbench.common.stunner.bpmn.client.shape.view.handler.EventInterruptingViewHandler;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseStartEvent;
@@ -29,7 +29,6 @@ import org.kie.workbench.common.stunner.bpmn.definition.StartMessageEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartSignalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.StartTimerEvent;
-import org.kie.workbench.common.stunner.core.client.shape.SvgDataUriGlyph;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle;
 import org.kie.workbench.common.stunner.core.client.shape.view.handler.CompositeShapeViewHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.handler.FontHandler;
@@ -55,18 +54,18 @@ public class StartEventShapeDef
                     .put(StartErrorEvent.class,
                          BPMNSVGViewFactory::startErrorEvent);
 
-    public static final Map<Class<? extends BaseStartEvent>, SvgDataUriGlyph> GLYPHS =
-            new HashMap<Class<? extends BaseStartEvent>, SvgDataUriGlyph>() {{
+    public static final Map<Class<? extends BaseStartEvent>, Glyph> GLYPHS =
+            new HashMap<Class<? extends BaseStartEvent>, Glyph>() {{
                 put(StartNoneEvent.class,
-                    BPMNSVGGlyphFactory.START_NONE_EVENT_GLYPH);
+                    BPMNGlyphFactory.EVENT_START_NONE);
                 put(StartTimerEvent.class,
-                    BPMNSVGGlyphFactory.START_TIMER_EVENT_GLYPH);
+                    BPMNGlyphFactory.EVENT_START_TIMER);
                 put(StartSignalEvent.class,
-                    BPMNSVGGlyphFactory.START_SIGNAL_EVENT_GLYPH);
+                    BPMNGlyphFactory.EVENT_START_SIGNAL);
                 put(StartMessageEvent.class,
-                    BPMNSVGGlyphFactory.START_MESSAGE_EVENT_GLYPH);
+                    BPMNGlyphFactory.EVENT_START_MESSAGE);
                 put(StartErrorEvent.class,
-                    BPMNSVGGlyphFactory.START_ERROR_EVENT_GLYPH);
+                    BPMNGlyphFactory.EVENT_START_ERROR);
             }};
 
     @Override
