@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.bpmn.client.forms.fields.assignmentsEdi
 
 import java.util.ArrayList;
 import java.util.List;
+
 import javax.enterprise.event.Event;
 
 import com.google.gwt.core.client.GWT;
@@ -40,8 +41,15 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.workbench.events.NotificationEvent;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.mockito.Matchers.anyBoolean;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyInt;
+import static org.mockito.Mockito.doCallRealMethod;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ActivityDataIOEditorWidgetViewImplTest {
@@ -89,6 +97,7 @@ public class ActivityDataIOEditorWidgetViewImplTest {
         doCallRealMethod().when(view).getAssignmentRows();
         doCallRealMethod().when(view).getAssignmentWidget(anyInt());
         doCallRealMethod().when(view).getAssignmentsCount();
+        doCallRealMethod().when(view).setReadOnly(anyBoolean());
         rows = new ArrayList<AssignmentRow>();
         rows.add(new AssignmentRow("varName",
                                    null,
@@ -178,4 +187,24 @@ public class ActivityDataIOEditorWidgetViewImplTest {
         view.getAssignmentWidget(123);
         verify(assignments).getComponent(123);
     }
+
+    @Test
+    public void testSetReadOnlyTrue() {
+        view.setReadOnly(true);
+        verify(button,
+               times(1)).setEnabled(false);
+        for (int i = 0; i < view.getAssignmentsCount(); i++) {
+            view.getAssignmentWidget(i).setReadOnly(true);
+        }
+    }
+
+    @Test
+    public void testSetReadOnlyFalse() {
+        view.setReadOnly(false);
+        verify(button,
+               times(1)).setEnabled(true);
+        for (int i = 0; i < view.getAssignmentsCount(); i++) {
+            view.getAssignmentWidget(i).setReadOnly(false);
+        }
+    }
 }
