@@ -18,6 +18,7 @@ package org.kie.workbench.common.stunner.bpmn.client.forms.fields.assignmentsEdi
 
 import java.util.HashSet;
 import java.util.Set;
+
 import javax.enterprise.event.Event;
 
 import com.google.gwt.event.dom.client.BlurEvent;
@@ -45,8 +46,19 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.workbench.events.NotificationEvent;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNull;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyBoolean;
+import static org.mockito.Mockito.anySet;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doCallRealMethod;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class AssignmentListItemWidgetViewImplTest {
@@ -135,6 +147,7 @@ public class AssignmentListItemWidgetViewImplTest {
         doCallRealMethod().when(view).setDisallowedNames(anySet(),
                                                          anyString());
         doCallRealMethod().when(view).handleDeleteButton(any(ClickEvent.class));
+        doCallRealMethod().when(view).setReadOnly(anyBoolean());
         AssignmentRow row = new AssignmentRow();
         doReturn(row).when(assignment).getModel();
     }
@@ -319,4 +332,30 @@ public class AssignmentListItemWidgetViewImplTest {
         view.handleDeleteButton(null);
         verify(widget).removeAssignment(model);
     }
+
+    @Test
+    public void testSetReadOnlyTrue() {
+        view.setReadOnly(true);
+        verify(name,
+               times(1)).setReadOnly(true);
+        verify(dataType,
+               times(1)).setEnabled(false);
+        verify(processVar,
+               times(1)).setEnabled(false);
+        verify(deleteButton,
+               times(1)).setEnabled(false);
+    }
+
+    @Test
+    public void testSetReadOnlyFalse() {
+        view.setReadOnly(false);
+        verify(name,
+               times(1)).setReadOnly(false);
+        verify(dataType,
+               times(1)).setEnabled(true);
+        verify(processVar,
+               times(1)).setEnabled(true);
+        verify(deleteButton,
+               times(1)).setEnabled(true);
+    }
 }
