@@ -37,8 +37,7 @@ public class EventCancelActivityViewHandlerTest extends EventViewHandlerTestBase
     @SuppressWarnings("unchecked")
     public void init() {
         super.init();
-        when(child1.getId()).thenReturn(EventCancelActivityViewHandler.ID_INTERMEDIATE);
-        when(child2.getId()).thenReturn(EventCancelActivityViewHandler.ID_INTERMEDIATE_NON_INTERRUPTING);
+        when(child1.getPrimitiveId()).thenReturn(EventCancelActivityViewHandler.ID_INTERMEDIATE);
         tested = new EventCancelActivityViewHandler();
     }
 
@@ -46,75 +45,75 @@ public class EventCancelActivityViewHandlerTest extends EventViewHandlerTestBase
     @SuppressWarnings("unchecked")
     public void testHandleTimerIsNotCancel() {
         final IntermediateTimerEvent bean =
-                new IntermediateTimerEvent.IntermediateTimerEventBuilder().build();
+                new IntermediateTimerEvent();
         bean.getExecutionSet().getCancelActivity().setValue(false);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(0d));
-        verify(prim2).setAlpha(eq(1d));
+        verify(prim1).setFillAlpha(eq(0d));
+        verify(prim1).setStrokeAlpha(eq(1d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleTimerIsCancel() {
         final IntermediateTimerEvent bean =
-                new IntermediateTimerEvent.IntermediateTimerEventBuilder().build();
+                new IntermediateTimerEvent();
 
         bean.getExecutionSet().getCancelActivity().setValue(true);
         tested.handle(bean, view);
 
-        verify(prim1).setAlpha(eq(1d));
-        verify(prim2).setAlpha(eq(0d));
+        verify(prim1).setFillAlpha(eq(1d));
+        verify(prim1).setStrokeAlpha(eq(0d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleSignalIsNotCancel() {
         final IntermediateSignalEventCatching bean =
-                new IntermediateSignalEventCatching.IntermediateSignalEventCatchingBuilder().build();
+                new IntermediateSignalEventCatching();
 
         bean.getExecutionSet().getCancelActivity().setValue(false);
         tested.handle(bean, view);
 
-        verify(prim1).setAlpha(eq(0d));
-        verify(prim2).setAlpha(eq(1d));
+        verify(prim1).setFillAlpha(eq(0d));
+        verify(prim1).setStrokeAlpha(eq(1d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleSignalIsCancel() {
         final IntermediateSignalEventCatching bean =
-                new IntermediateSignalEventCatching.IntermediateSignalEventCatchingBuilder().build();
+                new IntermediateSignalEventCatching();
 
         bean.getExecutionSet().getCancelActivity().setValue(true);
         tested.handle(bean, view);
 
-        verify(prim1).setAlpha(eq(1d));
-        verify(prim2).setAlpha(eq(0d));
+        verify(prim1).setFillAlpha(eq(1d));
+        verify(prim1).setStrokeAlpha(eq(0d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleMessageIsNotCancel() {
         final IntermediateMessageEventCatching bean =
-                new IntermediateMessageEventCatching.IntermediateMessageEventCatchingBuilder().build();
+                new IntermediateMessageEventCatching();
 
         bean.getExecutionSet().getCancelActivity().setValue(false);
         tested.handle(bean, view);
 
-        verify(prim1).setAlpha(eq(0d));
-        verify(prim2).setAlpha(eq(1d));
+        verify(prim1).setFillAlpha(eq(0d));
+        verify(prim1).setStrokeAlpha(eq(1d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleMessageIsCancel() {
         final IntermediateMessageEventCatching bean =
-                new IntermediateMessageEventCatching.IntermediateMessageEventCatchingBuilder().build();
+                new IntermediateMessageEventCatching();
 
         bean.getExecutionSet().getCancelActivity().setValue(true);
         tested.handle(bean, view);
 
-        verify(prim1).setAlpha(eq(1d));
-        verify(prim2).setAlpha(eq(0d));
+        verify(prim1).setFillAlpha(eq(1d));
+        verify(prim1).setStrokeAlpha(eq(0d));
     }
 }
