@@ -37,68 +37,67 @@ public class EventInterruptingViewHandlerTest extends EventViewHandlerTestBase {
     @SuppressWarnings("unchecked")
     public void init() {
         super.init();
-        when(child1.getId()).thenReturn(EventInterruptingViewHandler.ID_START);
-        when(child2.getId()).thenReturn(EventInterruptingViewHandler.ID_START_NON_INTERRUPTING);
+        when(child1.getPrimitiveId()).thenReturn(EventInterruptingViewHandler.ID_START);
         tested = new EventInterruptingViewHandler();
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleTimerIsNotInterrupting() {
-        final StartTimerEvent bean = new StartTimerEvent.StartTimerEventBuilder().build();
+        final StartTimerEvent bean = new StartTimerEvent();
         bean.getExecutionSet().getIsInterrupting().setValue(false);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(0d));
-        verify(prim2).setAlpha(eq(1d));
+        verify(prim1).setFillAlpha(eq(0d));
+        verify(prim1).setStrokeAlpha(eq(1d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleTimerIsInterrupting() {
-        final StartTimerEvent bean = new StartTimerEvent.StartTimerEventBuilder().build();
+        final StartTimerEvent bean = new StartTimerEvent();
         bean.getExecutionSet().getIsInterrupting().setValue(true);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(1d));
-        verify(prim2).setAlpha(eq(0d));
+        verify(prim1).setFillAlpha(eq(1d));
+        verify(prim1).setStrokeAlpha(eq(0d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleMessageEventIsNotInterrupting() {
-        final StartMessageEvent bean = new StartMessageEvent.StartMessageEventBuilder().build();
+        final StartMessageEvent bean = new StartMessageEvent();
         bean.getExecutionSet().getIsInterrupting().setValue(false);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(0d));
-        verify(prim2).setAlpha(eq(1d));
+        verify(prim1).setFillAlpha(eq(0d));
+        verify(prim1).setStrokeAlpha(eq(1d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleMessageEventIsInterrupting() {
-        final StartMessageEvent bean = new StartMessageEvent.StartMessageEventBuilder().build();
+        final StartMessageEvent bean = new StartMessageEvent();
         bean.getExecutionSet().getIsInterrupting().setValue(true);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(1d));
-        verify(prim2).setAlpha(eq(0d));
+        verify(prim1).setFillAlpha(eq(1d));
+        verify(prim1).setStrokeAlpha(eq(0d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleSignalEventIsNotInterrupting() {
-        final StartSignalEvent bean = new StartSignalEvent.StartSignalEventBuilder().build();
+        final StartSignalEvent bean = new StartSignalEvent();
         bean.getExecutionSet().getIsInterrupting().setValue(false);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(0d));
-        verify(prim2).setAlpha(eq(1d));
+        verify(prim1).setFillAlpha(eq(0d));
+        verify(prim1).setStrokeAlpha(eq(1d));
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testHandleSignalEventIsInterrupting() {
-        final StartSignalEvent bean = new StartSignalEvent.StartSignalEventBuilder().build();
+        final StartSignalEvent bean = new StartSignalEvent();
         bean.getExecutionSet().getIsInterrupting().setValue(true);
         tested.handle(bean, view);
-        verify(prim1).setAlpha(eq(1d));
-        verify(prim2).setAlpha(eq(0d));
+        verify(prim1).setFillAlpha(eq(1d));
+        verify(prim1).setStrokeAlpha(eq(0d));
     }
 }
