@@ -41,6 +41,7 @@ import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilderImpl;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
 import org.uberfire.ext.editor.commons.client.menu.RestoreVersionCommandProvider;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.editor.commons.version.VersionService;
@@ -134,6 +135,12 @@ abstract class KieMultipleDocumentEditorTestBase {
     @Mock
     protected EventSourceMock<NotificationEvent> notificationEvent;
 
+    @Mock
+    protected DownloadMenuItem downloadMenuItem;
+
+    @Mock
+    protected MenuItem downloadMenuItemButton;
+
     protected Command concurrentRenameCommand;
     protected Command concurrentDeleteCommand;
 
@@ -178,18 +185,21 @@ abstract class KieMultipleDocumentEditorTestBase {
         wrapped.setFileMenuBuilder(fileMenuBuilder);
         wrapped.setFileNameValidator(fileNameValidator);
         wrapped.setAssetUpdateValidator(assetUpdateValidator);
+        wrapped.setDownloadMenuItem(downloadMenuItem);
 
         this.editor = spy(wrapped);
 
         when(versionRecordManager.newSaveMenuItem(any(Command.class))).thenReturn(saveMenuItem);
         when(versionRecordManager.buildMenu()).thenReturn(versionManagerMenuItem);
-        
+
         // Setup defaults for nothing active in context that can be overriden in individual tests
         when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
         when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
         when(workbenchContext.getActiveModule()).thenReturn(Optional.empty());
         when(workbenchContext.getActiveRepositoryRoot()).thenReturn(Optional.empty());
         when(workbenchContext.getActivePackage()).thenReturn(Optional.empty());
+
+        when(downloadMenuItem.build(any())).thenReturn(downloadMenuItemButton);
     }
 
     protected TestDocument createTestDocument() {
